Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(645)

Unified Diff: components/html_viewer/html_document.h

Issue 1674903003: Extract shell methods from ApplicationImpl into a base class, and pass this to Initialize() instead. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@mojom
Patch Set: . Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/html_viewer/global_state.cc ('k') | components/html_viewer/html_document.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/html_viewer/html_document.h
diff --git a/components/html_viewer/html_document.h b/components/html_viewer/html_document.h
index 2eb5d6e3aa17603c8758a7ac3a8b04bbb8871a6e..453d2dfacb66fd01ef4ab9a8c72e0c4c9fc18bac 100644
--- a/components/html_viewer/html_document.h
+++ b/components/html_viewer/html_document.h
@@ -60,10 +60,10 @@ class HTMLDocument
using DeleteCallback = base::Callback<void(HTMLDocument*)>;
// Load a new HTMLDocument with |response|.
// |html_document_app| is the application this app was created in, and
// |connection| the specific connection triggering this new instance.
// |setup| is used to obtain init type state (such as resources).
- HTMLDocument(mojo::ApplicationImpl* html_document_app,
+ HTMLDocument(mojo::Shell* html_document_shell,
mojo::ApplicationConnection* connection,
mojo::URLResponsePtr response,
GlobalState* setup,
@@ -111,7 +111,7 @@ class HTMLDocument
void OnConnectionLost(mus::WindowTreeConnection* connection) override;
// HTMLFrameDelegate:
- mojo::ApplicationImpl* GetApp() override;
+ mojo::Shell* GetShell() override;
HTMLFactory* GetHTMLFactory() override;
void OnFrameDidFinishLoad() override;
void OnFrameSwappedToRemote() override;
@@ -142,7 +142,7 @@ class HTMLDocument
mojo::InterfaceRequest<mus::mojom::WindowTreeClient> request) override;
scoped_ptr<mojo::AppRefCount> app_refcount_;
- mojo::ApplicationImpl* html_document_app_;
+ mojo::Shell* html_document_shell_;
mojo::ApplicationConnection* connection_;
// HTMLDocument owns these pointers; binding requests after document load.
« no previous file with comments | « components/html_viewer/global_state.cc ('k') | components/html_viewer/html_document.cc » ('j') | no next file with comments »
@@ -60,10 +60,10 @@ class HTMLDocument
using DeleteCallback = base::Callback<void(HTMLDocument*)>;
// Load a new HTMLDocument with |response|.
- // |html_document_app| is the application this app was created in, and
+ // |html_document_shell| is the application this app was created in, and
// |connection| the specific connection triggering this new instance.
// |setup| is used to obtain init type state (such as resources).

Powered by Google App Engine
This is Rietveld 408576698